<?php

/**

 * Appearance Settings

 *

 * @package aemydesign_Spa

 */



function aemydesign_spa_customize_register_appearance( $wp_customize ) {

    

    $wp_customize->add_panel( 

        'appearance_settings', 

        array(

            'title'       => __( 'Appearance Settings', 'aemydesign-spa' ),

            'priority'    => 25,

            'capability'  => 'edit_theme_options',

            'description' => __( 'Customize Typography, Background Image & Color.', 'aemydesign-spa' ),

        ) 

    );

    

    /** Typography */

    $wp_customize->add_section(

        'typography_settings',

        array(

            'title'    => __( 'Typography', 'aemydesign-spa' ),

            'priority' => 20,

            'panel'    => 'appearance_settings',

        )

    );

    

    /** Primary Font */

    $wp_customize->add_setting(

        'primary_font',

        array(

            'default'           => 'Nunito Sans',

            'sanitize_callback' => 'aemydesign_spa_sanitize_select'

        )

    );



    $wp_customize->add_control(

        new aemydesign_Spa_Select_Control(

            $wp_customize,

            'primary_font',

            array(

                'label'       => __( 'Primary Font', 'aemydesign-spa' ),

                'description' => __( 'Primary font of the site.', 'aemydesign-spa' ),

                'section'     => 'typography_settings',

                'choices'     => aemydesign_spa_get_all_fonts(), 

            )

        )

    );

    

    /** Secondary Font */

    $wp_customize->add_setting(

        'secondary_font',

        array(

            'default'           => 'Marcellus',

            'sanitize_callback' => 'aemydesign_spa_sanitize_select'

        )

    );



    $wp_customize->add_control(

        new aemydesign_Spa_Select_Control(

            $wp_customize,

            'secondary_font',

            array(

                'label'       => __( 'Secondary Font', 'aemydesign-spa' ),

                'description' => __( 'Secondary font of the site.', 'aemydesign-spa' ),

                'section'     => 'typography_settings',

                'choices'     => aemydesign_spa_get_all_fonts(), 

            )

        )

    );



    /** Font Size*/

    $wp_customize->add_setting( 

        'font_size', 

        array(

            'default'           => 18,

            'sanitize_callback' => 'aemydesign_spa_sanitize_number_absint'

        ) 

    );

    

    $wp_customize->add_control(

        new aemydesign_Spa_Slider_Control( 

            $wp_customize,

            'font_size',

            array(

                'section'     => 'typography_settings',

                'label'       => __( 'Font Size', 'aemydesign-spa' ),

                'description' => __( 'Change the font size of your site.', 'aemydesign-spa' ),

                'choices'     => array(

                    'min'   => 10,

                    'max'   => 50,

                    'step'  => 1,

                )                 

            )

        )

    );

    

    $wp_customize->add_setting(

        'ed_localgoogle_fonts',

        array(

            'default'           => false,

            'sanitize_callback' => 'aemydesign_spa_sanitize_checkbox',

        )

    );

    

    $wp_customize->add_control(

        new aemydesign_Spa_Toggle_Control( 

            $wp_customize,

            'ed_localgoogle_fonts',

            array(

                'section'       => 'typography_settings',

                'label'         => __( 'Load Google Fonts Locally', 'aemydesign-spa' ),

                'description'   => __( 'Enable to load google fonts from your own server instead from google\'s CDN. This solves privacy concerns with Google\'s CDN and their sometimes less-than-transparent policies.', 'aemydesign-spa' )

            )

        )

    );   



    $wp_customize->add_setting(

        'ed_preload_local_fonts',

        array(

            'default'           => false,

            'sanitize_callback' => 'aemydesign_spa_sanitize_checkbox',

        )

    );

    

    $wp_customize->add_control(

        new aemydesign_Spa_Toggle_Control( 

            $wp_customize,

            'ed_preload_local_fonts',

            array(

                'section'       => 'typography_settings',

                'label'         => __( 'Preload Local Fonts', 'aemydesign-spa' ),

                'description'   => __( 'Preloading Google fonts will speed up your website speed.', 'aemydesign-spa' ),

                'active_callback' => 'aemydesign_spa_ed_localgoogle_fonts'

            )

        )

    );   



    ob_start(); ?>

        

        <span style="margin-bottom: 5px;display: block;"><?php esc_html_e( 'Click the button to reset the local fonts cache', 'aemydesign-spa' ); ?></span>

        

        <input type="button" class="button button-primary aemydesign-spa-flush-local-fonts-button" name="aemydesign-spa-flush-local-fonts-button" value="<?php esc_attr_e( 'Flush Local Font Files', 'aemydesign-spa' ); ?>" />

    <?php

    $aemydesign_spa_flush_button = ob_get_clean();



    $wp_customize->add_setting(

        'ed_flush_local_fonts',

        array(

            'sanitize_callback' => 'wp_kses_post',

        )

    );

    

    $wp_customize->add_control(

        'ed_flush_local_fonts',

        array(

            'label'         => __( 'Flush Local Fonts Cache', 'aemydesign-spa' ),

            'section'       => 'typography_settings',

            'description'   => $aemydesign_spa_flush_button,

            'type'          => 'hidden',

            'active_callback' => 'aemydesign_spa_ed_localgoogle_fonts'

        )

    );



    /** Move Background Image section to appearance panel */

    $wp_customize->get_section( 'colors' )->panel              = 'appearance_settings';

    $wp_customize->get_section( 'colors' )->priority           = 10;

    $wp_customize->get_section( 'background_image' )->panel    = 'appearance_settings';

    $wp_customize->get_section( 'background_image' )->priority = 15;  

}

add_action( 'customize_register', 'aemydesign_spa_customize_register_appearance' );